@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.38'; # VERSION
+our $DATE = '2017-01-13'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,6 +53,8 @@ has per_arg_yaml => (is=>'rw');
 has validate_args => (is=>'rw');
 has pack_deps => (is=>'rw');
 
+has inline_generate_completer => (is=>'rw', default=>1);
+
 sub mvp_multivalue_args { qw(build_load_modules load_modules code_before_instantiate_cmdline code_after_end config_filename config_dirs allow_prereq) }
 
 sub gather_files {
@@ -216,7 +218,7 @@ sub munge_files {
     # create a separate completion script if we use Perinci::CmdLine::Inline,
     # because Perinci::CmdLine::Inline currently does not support completion
     # natively.
-    if ($res->[3]{'func.cmdline_module_inlined'}) {
+    if ($res->[3]{'func.cmdline_module_inlined'} && $self->inline_generate_completer) {
         require App::GenPericmdCompleterScript;
         my $compres = App::GenPericmdCompleterScript::gen_pericmd_completer_script(
             url => $self->url,
@@ -254,7 +256,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.38 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-12.
+This document describes version 0.39 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-01-13.
 
 =head1 SYNOPSIS
 
@@ -436,6 +438,13 @@ Will be passed to Perinci::CmdLine::Gen backend.
 
 =head1 CONFIGURATION (OTHER)
 
+=head2 inline_generate_completer => bool (default: 1)
+
+Perinci::CmdLine::Inline-generated scripts currently cannot do shell completion
+on its own, but relies on a separate completer script (e.g. if the script is
+C<bin/foo> then the completer will be generated at C<bin/_foo>). This option can
+be used to suppress the generation of completer script.
+
 =head2 build_load_modules => array[str]
 
 Load modules during build process.
@@ -446,7 +455,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
 
 =head1 BUGS
 
